.. image:: ../artwork/logo.png
  :width: 200px
  :align: right

API Reference
=============

Contents:

.. toctree::
   :maxdepth: 2

   graphcat.rst
   graphcat.common.rst
   graphcat.diagram.rst
   graphcat.dynamic.rst
   graphcat.graph.rst
   graphcat.notebook.rst
   graphcat.optional.rst
   graphcat.require.rst
   graphcat.static.rst
   graphcat.streaming.rst
